===============================
Python Boilerplate
===============================

.. image:: https://img.shields.io/travis/fxs007/boiler-plate.svg
        :target: https://travis-ci.org/fxs007/boiler-plate

.. image:: https://img.shields.io/pypi/v/boiler-plate.svg
        :target: https://pypi.python.org/pypi/boiler-plate


Python Boilerplate contains all the boilerplate you need to create a Python package.

* Free software: MIT license
* Documentation: (COMING SOON!) https://fxs007-boiler-plate.readthedocs.org.

Features
--------

* TODO
